pub struct ModuleListener { /* private fields */ }Expand description
An owned listener for module events.
This is created by ModuleListenerLocalBuilder and will receive events as long as it is alive.
When this gets dropped, the listener gets unregistered and no events will be received by it.